[Lldb-commits] [lldb] r131848 - in /lldb/trunk: source/Commands/CommandObjectBreakpointCommand.cpp source/Commands/CommandObjectBreakpointCommand.h test/abbreviation_tests/TestAbbreviations.py test/breakpoint_command/TestBreakpointCommand.py

Caroline Tice ctice at apple.com
Sun May 22 00:14:46 PDT 2011


Author: ctice
Date: Sun May 22 02:14:46 2011
New Revision: 131848

URL: http://llvm.org/viewvc/llvm-project?rev=131848&view=rev
Log:

Change the command 'breakpoint command remove' to 'breakpoint command delete',
to be more consistent with other commands.


Modified:
    lldb/trunk/source/Commands/CommandObjectBreakpointCommand.cpp
    lldb/trunk/source/Commands/CommandObjectBreakpointCommand.h
    lldb/trunk/test/abbreviation_tests/TestAbbreviations.py
    lldb/trunk/test/breakpoint_command/TestBreakpointCommand.py

Modified: lldb/trunk/source/Commands/CommandObjectBreakpointCommand.cpp
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Commands/CommandObjectBreakpointCommand.cpp?rev=131848&r1=131847&r2=131848&view=diff
==============================================================================
--- lldb/trunk/source/Commands/CommandObjectBreakpointCommand.cpp (original)
+++ lldb/trunk/source/Commands/CommandObjectBreakpointCommand.cpp Sun May 22 02:14:46 2011
@@ -520,13 +520,13 @@
 
 
 //-------------------------------------------------------------------------
-// CommandObjectBreakpointCommandRemove
+// CommandObjectBreakpointCommandDelete
 //-------------------------------------------------------------------------
 
-CommandObjectBreakpointCommandRemove::CommandObjectBreakpointCommandRemove (CommandInterpreter &interpreter) :
+CommandObjectBreakpointCommandDelete::CommandObjectBreakpointCommandDelete (CommandInterpreter &interpreter) :
     CommandObject (interpreter, 
-                   "remove",
-                   "Remove the set of commands from a breakpoint.",
+                   "delete",
+                   "Delete the set of commands from a breakpoint.",
                    NULL)
 {
     CommandArgumentEntry arg;
@@ -543,12 +543,12 @@
     m_arguments.push_back (arg);
 }
 
-CommandObjectBreakpointCommandRemove::~CommandObjectBreakpointCommandRemove ()
+CommandObjectBreakpointCommandDelete::~CommandObjectBreakpointCommandDelete ()
 {
 }
 
 bool
-CommandObjectBreakpointCommandRemove::Execute 
+CommandObjectBreakpointCommandDelete::Execute 
 (
     Args& command,
     CommandReturnObject &result
@@ -558,7 +558,7 @@
 
     if (target == NULL)
     {
-        result.AppendError ("There is not a current executable; there are no breakpoints from which to remove commands");
+        result.AppendError ("There is not a current executable; there are no breakpoints from which to delete commands");
         result.SetStatus (eReturnStatusFailed);
         return false;
     }
@@ -568,14 +568,14 @@
 
     if (num_breakpoints == 0)
     {
-        result.AppendError ("No breakpoints exist to have commands removed");
+        result.AppendError ("No breakpoints exist to have commands deleted");
         result.SetStatus (eReturnStatusFailed);
         return false;
     }
 
     if (command.GetArgumentCount() == 0)
     {
-        result.AppendError ("No breakpoint specified from which to remove the commands");
+        result.AppendError ("No breakpoint specified from which to delete the commands");
         result.SetStatus (eReturnStatusFailed);
         return false;
     }
@@ -760,15 +760,15 @@
 {
     bool status;
     CommandObjectSP add_command_object (new CommandObjectBreakpointCommandAdd (interpreter));
-    CommandObjectSP remove_command_object (new CommandObjectBreakpointCommandRemove (interpreter));
+    CommandObjectSP delete_command_object (new CommandObjectBreakpointCommandDelete (interpreter));
     CommandObjectSP list_command_object (new CommandObjectBreakpointCommandList (interpreter));
 
     add_command_object->SetCommandName ("breakpoint command add");
-    remove_command_object->SetCommandName ("breakpoint command remove");
+    delete_command_object->SetCommandName ("breakpoint command delete");
     list_command_object->SetCommandName ("breakpoint command list");
 
     status = LoadSubCommand ("add",    add_command_object);
-    status = LoadSubCommand ("remove", remove_command_object);
+    status = LoadSubCommand ("delete", delete_command_object);
     status = LoadSubCommand ("list",   list_command_object);
 }
 

Modified: lldb/trunk/source/Commands/CommandObjectBreakpointCommand.h
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/source/Commands/CommandObjectBreakpointCommand.h?rev=131848&r1=131847&r2=131848&view=diff
==============================================================================
--- lldb/trunk/source/Commands/CommandObjectBreakpointCommand.h (original)
+++ lldb/trunk/source/Commands/CommandObjectBreakpointCommand.h Sun May 22 02:14:46 2011
@@ -130,16 +130,16 @@
 };
 
 //-------------------------------------------------------------------------
-// CommandObjectBreakpointCommandRemove
+// CommandObjectBreakpointCommandDelete
 //-------------------------------------------------------------------------
 
-class CommandObjectBreakpointCommandRemove : public CommandObject
+class CommandObjectBreakpointCommandDelete : public CommandObject
 {
 public:
-    CommandObjectBreakpointCommandRemove (CommandInterpreter &interpreter);
+    CommandObjectBreakpointCommandDelete (CommandInterpreter &interpreter);
 
     virtual
-    ~CommandObjectBreakpointCommandRemove ();
+    ~CommandObjectBreakpointCommandDelete ();
 
     virtual bool
     Execute (Args& command,

Modified: lldb/trunk/test/abbreviation_tests/TestAbbreviations.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/abbreviation_tests/TestAbbreviations.py?rev=131848&r1=131847&r2=131848&view=diff
==============================================================================
--- lldb/trunk/test/abbreviation_tests/TestAbbreviations.py (original)
+++ lldb/trunk/test/abbreviation_tests/TestAbbreviations.py Sun May 22 02:14:46 2011
@@ -94,7 +94,7 @@
                                 "Breakpoint commands:",
                                 "print frame" ])
 
-        self.runCmd("br co rem 1")
+        self.runCmd("br co del 1")
         self.expect("breakpoint command list 1",
                     startstr = "Breakpoint 1 does not have an associated command.")
 

Modified: lldb/trunk/test/breakpoint_command/TestBreakpointCommand.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/breakpoint_command/TestBreakpointCommand.py?rev=131848&r1=131847&r2=131848&view=diff
==============================================================================
--- lldb/trunk/test/breakpoint_command/TestBreakpointCommand.py (original)
+++ lldb/trunk/test/breakpoint_command/TestBreakpointCommand.py Sun May 22 02:14:46 2011
@@ -1,5 +1,5 @@
 """
-Test lldb breakpoint command add/list/remove.
+Test lldb breakpoint command add/list/delete.
 """
 
 import os, time
@@ -18,13 +18,13 @@
 
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym(self):
         """Test a sequence of breakpoint command add, list, and remove."""
         self.buildDsym()
         self.breakpoint_command_sequence()
         self.breakpoint_command_script_parameters ()
 
     def test_with_dwarf(self):
         """Test a sequence of breakpoint command add, list, and remove."""
         self.buildDwarf()
         self.breakpoint_command_sequence()
         self.breakpoint_command_script_parameters ()
@@ -36,7 +36,7 @@
         self.line = line_number('main.c', '// Set break point at this line.')
 
     def breakpoint_command_sequence(self):
         """Test a sequence of breakpoint command add, list, and remove."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
 
@@ -98,7 +98,7 @@
         self.runCmd("process continue")
 
         # Remove the breakpoint command associated with breakpoint 1.
-        self.runCmd("breakpoint command remove 1")
+        self.runCmd("breakpoint command delete 1")
 
         # Remove breakpoint 2.
         self.runCmd("breakpoint delete 2")
@@ -18,13 +18,13 @@
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     def test_with_dsym(self):
-        """Test a sequence of breakpoint command add, list, and remove."""
+        """Test a sequence of breakpoint command add, list, and delete."""
         self.buildDsym()
         self.breakpoint_command_sequence()
@@ -18,13 +18,13 @@
 
     def test_with_dwarf(self):
-        """Test a sequence of breakpoint command add, list, and remove."""
+        """Test a sequence of breakpoint command add, list, and delete."""
         self.buildDwarf()
         self.breakpoint_command_sequence()
@@ -36,7 +36,7 @@
 
     def breakpoint_command_sequence(self):
-        """Test a sequence of breakpoint command add, list, and remove."""
+        """Test a sequence of breakpoint command add, list, and delete."""
         exe = os.path.join(os.getcwd(), "a.out")
         self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)





More information about the lldb-commits mailing list